# Assignment_03

**Codelab Link:** 

**Streamlit link:** 



The goal of this assignment was to create a platform to retrieve GOES18 and Nexrad data from NOAA AWS S3 buckets, and then enable the user to be able to choose files based on features like Station, Year, Date and hour.

Functionalities included







#### Steps to run the project









#### Attestation
WE ATTEST THAT WE HAVEN’T USED ANY OTHER STUDENTS WORK IN OUR ASSIGNMENT AND ABIDE BY THE POLICIES LISTED IN THE STUDENT HANDBOOK



Contribution:
- Dhanush Kumar Shankar: 25%
- Nishanth Prasath: 25%
- Shubham Goyal: 25%
- Subhash Chandran Shankarakumar: 25%
